from .matrices import matrix_delta
from .matrices import matrix_toeplitz


from .tensors import tensor_const
from .tensors import tensor_delta
from .tensors import tensor_poly
from .tensors import tensor_rand


from .vectors import vector_delta
